pub fn iter_join(
separator: &str,
iter: impl IntoIterator<Item: Display> + Clone,
) -> impl DisplayExpand description
Formats an iterator as an object whose display implementation is a separator-separated string
of items from iter.
Performs a similar function to Itertools::format. Differences:
Itertools::formatpanics if the returned formatting helper is formatted twice; conversely,iter_joinrequires that the iterator beClone.iter_joinonly supportsDisplay;.formatsupports all formatting traits.iter_joinaccepts anIntoIteratorrather than requiring anIterator.