Intern

Struct Intern 

pub struct Intern<T: ?Sized>(/* private fields */);
A wrapper around Arc representing owned InternCache entries.

The wrapper type serves the purpose of semantic meaning only, implying that this value is cached in some way or another by this module.

We only conveniently allow obtaining the underlying Arc with a From but not the other way around. This means that interfacing code can make the type to “forget” it originated from an InternCache but not the other way around, i.e. cannot accidentally create fake entries that look like they came from an InternCache. If one really has to circumvent this, then the Intern::new_uncached_uninterned() method exists.

This ensures that interning is done everywhere that it’s expected, avoiding excess memory usage.

Implementations

Source

impl<T: ?Sized> Intern<T>

pub fn new_uncached_uninterned(value: Arc<T>) -> Intern<T>

Creates an Intern from an arbitrary Arc.

The use of this is generally discouraged, as it effectively destroys the boundary of implying that certain cache entries come from the InternCache.