FilterCount

Struct FilterCount 

pub struct FilterCount {
    pub n_accepted: usize,
    pub n_rejected: usize,
}
A record of how many items a CountingFilter returned by IteratorExt::filter_cnt accepted and rejected.

In tor-guardmgr we use this type to keep track of which filters reject which guards.

Fields

n_accepted: usize

The number of items that the filter considered and accepted.

n_rejected: usize

The number of items that the filter considered and accepted.

Implementations

Source

impl FilterCount

pub fn display_frac_rejected(&self) -> DisplayFracRejected<'_>

Return a wrapper that can be displayed as the fraction of rejected items.

Example
let mut count = FilterCount::default();
let sum_of_evens : u32 = (1..=10)
    .filter_cnt(&mut count, |x| *x % 2 == 0)
    .sum();
assert_eq!(format!("Rejected {} as odd", count.display_frac_rejected()),
    "Rejected 5/10 as odd".to_string());
pub fn count(&mut self, accept: bool) -> bool

Count and return the provided boolean value.

This is an alternative way to use FilterCount when you have to provide a function that takes a predicate rather than a member of an iterator chain.

Example
let mut count = FilterCount::default();
let mut emoji = "Hello 🙂 World 🌏!".to_string();
emoji.retain(|ch| count.count(!ch.is_ascii()));
assert_eq!(emoji, "🙂🌏");
assert_eq!(count, FilterCount { n_accepted: 2, n_rejected: 14});