derive_deftly_template_GloballyInternable

Macro derive_deftly_template_GloballyInternable 

macro_rules! derive_deftly_template_GloballyInternable {
    ({ $($driver:tt)* } [$($aoptions:tt)*] ($($future:tt)*) $($tpassthrough:tt)*) => { ... };
    ($($wrong:tt)*) => { ... };
}
Implement the GloballyInternable trait for a specific type.

The implementation in itself is trivial and straightforward with this macro primarily serving as a convenience method.

This is a derive_deftly template. Do not invoke it directly. To use it, write: #[derive(Deftly)] #[derive_deftly(GloballyInternable)].