#[non_exhaustive]pub enum OnionperfCircuitStatus {
Built,
Launched,
Extended,
Closed,
Failed,
}Expand description
A circuit status that is intended to be ingested by onionperf.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Built
A new circuit was built (BUILT in C Tor).
Launched
This tunnel is now usable (LAUNCHED in C Tor).
Extended
This circuit was successfully extended by another hop (EXTENDED in C Tor).
Closed
This circuit was closed, either cleanly or due to an error (CLOSED in C Tor).
Failed
This tunnel was not successfully created (FAILED in C Tor).