#[non_exhaustive]pub enum OnionperfEvent {
Stream(OnionperfStreamStatus),
Circuit(OnionperfCircuitStatus),
Guard(OnionperfGuardStatus),
}Expand description
An event that is intended to be ingested by onionperf.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Stream(OnionperfStreamStatus)
A stream-related event (STREAM in C Tor)
Note that this somewhat conflates SOCKS proxy streams and data streams, as C Tor does the same.
These can be distinguished, as the data streams have a stream ID set in the emitted events, while the SOCKS streams do not.
Circuit(OnionperfCircuitStatus)
A circuit-related event (CIRC in C Tor).
Guard(OnionperfGuardStatus)
A guard-related event (GUARD in C Tor).