#[non_exhaustive]pub enum OnionperfGuardStatus {
New,
Up,
Down,
Dropped,
}Expand description
A guard status that is intended to be ingested by onionperf.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
New
A new guard has been added to the set of available guards (NEW in C Tor).
Up
This guard has been used successfully (UP in C Tor).
Down
We attempted to use this guard but were not successful (DOWN in C Tor).
Dropped
This guard was removed from the set of available guards (DROPPED in C Tor).