#[non_exhaustive]pub enum OnionperfStreamStatus {
New,
Closed,
Failed,
}Expand description
A stream status that is intended to be ingested by onionperf.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
New
A stream was newly created (NEW in C Tor).
Closed
A stream was closed (CLOSED in C Tor).
Failed
A stream has failed and been closed due to an error (FAILED in C Tor).