decode_seed_bytes

Function decode_seed_bytes 

fn decode_seed_bytes(s: &str) -> Option<<TestingRng as SeedableRng>::Seed>
Try to see whether a literal seed can be decoded from a given string. If so, return it.

We currently use a hex encoding, truncating or zero-extending the provided seed as needed.