fn format_seed_bytes(seed: &<TestingRng as SeedableRng>::Seed) -> StringExpand description
Format seed in the format expected by decode_seed_bytes.
This is a separate function to make it clearer what the tests are testing.
fn format_seed_bytes(seed: &<TestingRng as SeedableRng>::Seed) -> StringFormat seed in the format expected by decode_seed_bytes.
This is a separate function to make it clearer what the tests are testing.