pub enum NeverEnoughTokensError {
ExceedsMaxTokens,
ZeroRate,
InstantNotRepresentable,
}Expand description
The token bucket will never have the requested number of tokens.
Variants
ExceedsMaxTokens
The request exceeds the bucket’s maximum number of tokens.
ZeroRate
The refill rate is 0.
InstantNotRepresentable
The time is not representable.
For example the if the rate is low and a large number of tokens were requested, it may be too far in the future that it cannot be represented as a time value.