pub struct ClaimedTokens<'a, I> {
bucket: &'a mut TokenBucket<I>,
count: u64,
}Expand description
A handle to a number of claimed tokens.
Dropping this handle will commit the claim.
Fields
bucket: &'a mut TokenBucket<I>The bucket that the claim is for.
count: u64How many tokens to remove from the bucket.
Implementations
Sourceimpl<'a, I> ClaimedTokens<'a, I>
impl<'a, I> ClaimedTokens<'a, I>
Sourcefn new(bucket: &'a mut TokenBucket<I>, count: u64) -> Self
fn new(bucket: &'a mut TokenBucket<I>, count: u64) -> Self
Create a new ClaimedTokens that will remove count tokens from the token bucket when
dropped.
Sourcepub fn commit(self) -> BecameEmpty
pub fn commit(self) -> BecameEmpty
Commit the claimed tokens.
This is equivalent to just dropping the ClaimedTokens, but also returns whether the
token bucket became empty or not.
Sourcepub fn reduce(&mut self, count: u64) -> Result<(), InsufficientTokensError>
pub fn reduce(&mut self, count: u64) -> Result<(), InsufficientTokensError>
Reduce the claim to a fewer number of tokens than the original claim.
If count is larger than the original claim, an error will be returned containing the
current number of claimed tokens.
Sourcefn commit_impl(&mut self) -> BecameEmpty
fn commit_impl(&mut self) -> BecameEmpty
The commit implementation.
After calling commit_impl(),
the ClaimedTokens should no longer be used and should be dropped immediately.