fn decode_seed_bytes(s: &str) -> Option<<TestingRng as SeedableRng>::Seed>Expand description
Try to see whether a literal seed can be decoded from a given string. If so, return it.
We currently use a hex encoding, truncating or zero-extending the provided seed as needed.