ClaimedTokens

Struct ClaimedTokens 

pub struct ClaimedTokens<'a, I> { /* private fields */ }
A handle to a number of claimed tokens.

Dropping this handle will commit the claim.

Implementations

Source

impl<'a, I> ClaimedTokens<'a, I>

pub fn commit(self) -> BecameEmpty

Commit the claimed tokens.

This is equivalent to just dropping the ClaimedTokens, but also returns whether the token bucket became empty or not.

pub fn reduce(&mut self, count: u64) -> Result<(), InsufficientTokensError>

Reduce the claim to a fewer number of tokens than the original claim.

If count is larger than the original claim, an error will be returned containing the current number of claimed tokens.

pub fn discard(self)

Discard the claim.

This does not remove any tokens from the token bucket.