pub struct InsufficientTokensError { /* private fields */ }Expand description
An operation was attempted to reduce the number of tokens, but the token bucket did not have enough tokens.
Implementations
Sourceimpl InsufficientTokensError
impl InsufficientTokensError
Sourcepub fn available_tokens(&self) -> u64
pub fn available_tokens(&self) -> u64
Get the number of tokens that are available to drain/commit.